package com.ruoyi.system.mapper.projectV2;

import java.util.List;
import com.ruoyi.system.domain.projectV2.ZsyzDjks;

/**
 * 招商引资_对接客商Mapper接口
 * 
 * @author ruoyi
 * @date 2023-03-16
 */
public interface ZsyzDjksMapper 
{
    /**
     * 查询招商引资_对接客商
     * 
     * @param id 招商引资_对接客商主键
     * @return 招商引资_对接客商
     */
    public ZsyzDjks selectZsyzDjksById(Long id);

    /**
     * 查询招商引资_对接客商列表
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 招商引资_对接客商集合
     */
    public List<ZsyzDjks> selectZsyzDjksList(ZsyzDjks zsyzDjks);

    /**
     * 新增招商引资_对接客商
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 结果
     */
    public int insertZsyzDjks(ZsyzDjks zsyzDjks);

    /**
     * 修改招商引资_对接客商
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 结果
     */
    public int updateZsyzDjks(ZsyzDjks zsyzDjks);

    /**
     * 删除招商引资_对接客商
     * 
     * @param id 招商引资_对接客商主键
     * @return 结果
     */
    public int deleteZsyzDjksById(Long id);

    /**
     * 批量删除招商引资_对接客商
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZsyzDjksByIds(Long[] ids);
}
