package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectV2.ZsyzDjks;
import com.ruoyi.system.service.projectV2.IZsyzDjksService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_对接客商Controller
 * 
 * @author ruoyi
 * @date 2023-03-16
 */
@RestController
@RequestMapping("/projectV2/djks")
public class ZsyzDjksController extends BaseController
{
    @Autowired
    private IZsyzDjksService zsyzDjksService;

    /**
     * 查询招商引资_对接客商列表
     */
    @PreAuthorize("@ss.hasPermi('system:djks:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzDjks zsyzDjks)
    {
        startPage();
        List<ZsyzDjks> list = zsyzDjksService.selectZsyzDjksList(zsyzDjks);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_对接客商列表
     */
    @PreAuthorize("@ss.hasPermi('system:djks:export')")
    @Log(title = "招商引资_对接客商", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzDjks zsyzDjks)
    {
        List<ZsyzDjks> list = zsyzDjksService.selectZsyzDjksList(zsyzDjks);
        ExcelUtil<ZsyzDjks> util = new ExcelUtil<ZsyzDjks>(ZsyzDjks.class);
        util.exportExcel(response, list, "招商引资_对接客商数据");
    }

    /**
     * 获取招商引资_对接客商详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:djks:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzDjksService.selectZsyzDjksById(id));
    }

    /**
     * 新增招商引资_对接客商
     */
    @PreAuthorize("@ss.hasPermi('system:djks:add')")
    @Log(title = "招商引资_对接客商", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzDjks zsyzDjks)
    {
        return toAjax(zsyzDjksService.insertZsyzDjks(zsyzDjks));
    }

    /**
     * 修改招商引资_对接客商
     */
    @PreAuthorize("@ss.hasPermi('system:djks:edit')")
    @Log(title = "招商引资_对接客商", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzDjks zsyzDjks)
    {
        return toAjax(zsyzDjksService.updateZsyzDjks(zsyzDjks));
    }

    /**
     * 删除招商引资_对接客商
     */
    @PreAuthorize("@ss.hasPermi('system:djks:remove')")
    @Log(title = "招商引资_对接客商", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzDjksService.deleteZsyzDjksByIds(ids));
    }
}
